freeze

fn freeze(built: BuiltPayload, supersedes: Vec<Uuid>) -> Decision<'static>
Only now does the row become claimable by import: the payload is frozen and the event records when the enrolment was resolved.