unsent_duplicate

pub(super) fn unsent_duplicate<'a>(
    lookup: &AnsweredLookup<'a>,
    message: &'static str,
) -> Decision<'a>
The row is not sent, because a credit it would not beat is already held, and moves to duplicate. The grade we would have sent stays on the row as the one a later regrade has to beat.